@@ -35,6 +35,19 @@ Okay, canceling this run. If you want to configure your project
 for deployment, run simple_deploy again without the --automate-all flag.
 """
 
+requires_platform_flag = """
+The --platform flag is required; you must specify which platform you want to 
+deploy your project to.
+- Current options are `heroku` and `platform_sh`.
+- Example usage:
+  $ python manage.py simple_deploy --platform heroku
+  $ python manage.py simple_deploy --platform platform_sh
+
+For more detailed information, see https://github.com/ehmatthes/django-simple-deploy/blob/main/docs/cli_args.md
+
+Please re-run the command with a --platform option specified.
+"""
+
 
 # --- Dynamic strings ---
 # These need to be generated in functions, to display information that's 
